==> react-localux-2.1.0.tgz: package/src/create-store.js <==
import createUseContext from 'constate';
import { useEffect, useMemo, useReducer, useRef } from 'react';
import { tryCreateDevToolsLogger } from './devtools';
export function useMethods(initialState, methods) {
    // To avoid warnings "Can't perform a React state update on an unmounted component"
    const isMounted = useRef(true);
    useEffect(() => () => {
        isMounted.current = false;
    }, []);
    const reducer = useMemo(() => {
        const logger = tryCreateDevToolsLogger();
        return (state, action) => {
            const nextState = methods[action.type](state)(...action.payload);
            if (logger) {
                logger(action, nextState);
            }
            return nextState;
        };
    }, []);
    const [state, dispatch] = useReducer(reducer, initialState);
    const methodsOut = useMemo(() => {
        const methodsOut = {};
        Object.keys(methods).forEach(type => {
            methodsOut[type] = (...payload) => {
                if (!isMounted.current) {
                    return;
                }
                dispatch({
                    type,
                    payload
                });
            };
        });
        return methodsOut;
    }, []);
    return { state, methods: methodsOut };
}
export const createUseStore = (defaultState, methodsIn) => createUseContext(({ initialState }) => useMethods(initialState || defaultState, methodsIn), 
// https://kentcdodds.com/blog/always-use-memo-your-context-value
// Pass to context not a new object every time
({ state }) => [state]);

==> react-localux-2.2.0.tgz: package/src/create-store.js <==
import createUseContext from 'constate';
import { useEffect, useMemo, useReducer, useRef } from 'react';
import { tryCreateDevToolsLogger } from './devtools';
export const keysOf = (obj) => Object.keys(obj);
export function useMethods(initialState, methods) {
    // To avoid warnings "Can't perform a React state update on an unmounted component"
    const isMounted = useRef(true);
    useEffect(() => () => {
        isMounted.current = false;
    }, []);
    const reducer = useMemo(() => {
        const logger = tryCreateDevToolsLogger();
        return (state, action) => {
            const nextState = methods[action.type](state)(...action.payload);
            if (logger) {
                logger(action, nextState);
            }
            return nextState;
        };
    }, []);
    const [state, dispatch] = useReducer(reducer, initialState);
    const methodsOut = useMemo(() => {
        const methodsOut = {};
        keysOf(methods).forEach(type => {
            methodsOut[type] = (...payload) => {
                if (!isMounted.current) {
                    return;
                }
                dispatch({
                    type,
                    payload
                });
            };
        });
        return methodsOut;
    }, []);
    return { state, methods: methodsOut };
}
export const createUseStore = (defaultState, methodsIn) => createUseContext(({ initialState }) => useMethods(initialState || defaultState, methodsIn), 
// https://kentcdodds.com/blog/always-use-memo-your-context-value
// Pass to context not a new object every time
({ state }) => [state]);
